@@ -1,5 +1,7 @@
 from .abc import AbstractDensifier, DensificationInstruct, DensifierWrapper, NoopDensifier
 from .trainer import DensificationTrainer
 from .densifier import SplitCloneDensifier, SplitCloneDensifierTrainerWrapper
+from .adaptive import AdaptiveSplitCloneDensifier, AdaptiveSplitCloneDensifierTrainerWrapper
 from .pruner import OpacityPruner, OpacityPrunerTrainerWrapper
 from .combinations import DensificationTrainerWrapper, BaseDensificationTrainer
+from .combinations import AdaptiveDensificationTrainerWrapper, AdaptiveDensificationTrainer
